boreal package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   boreal.audio_widgets

Submodules
----------

boreal.boreal module
--------------------

.. automodule:: boreal.boreal
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: boreal
   :members:
   :undoc-members:
   :show-inheritance:
